# Clipper2 DLL

The Clipper2 library is written in several languages (C++, C# & Delphi Pascal) and can be compiled and statically linked into applications using those languages. Now developers using other programming languages can also access almost all of Clipper2's features by dynamically linking to a C++ compiled library. Exported functions and their related data structures are well documented in [clipper.export.h](https://github.com/AngusJohnson/Clipper2/blob/main/CPP/Clipper2Lib/include/clipper2/clipper.export.h). And the latest precompiled DLLs can be found in [Clipper2's Releases](https://github.com/AngusJohnson/Clipper2/releases).

This folder contains: 
1.   C++ code that compiles **Clipper2** into Windows DLLs (both 32bit and 64bit).
2.   Several sample applications that demonstrate how to use these DLLs in non-C++ languages.
